# Yupy
## Dead simple Object schema validation for python
*Inspired by [**yup js library**](https://github.com/jquense/yup)*

Yupy is a schema builder for runtime value parsing and validation. Define a schema, transform a value to match, assert the shape of an existing value, or both. Yup schema are extremely expressive and allow modeling complex, interdependent validations, or value transformation.
